@@ -10,9 +10,18 @@
 # ruff: noqa: E402 - Module level import not at top of file
 # ruff: noqa: F401 - `var` imported but unused
 
+import platform
 from enum import Enum
 
-import numexpr
+# Do the platform check once at module level
+IS_WASM = platform.machine() == "wasm32"
+# IS_WASM = True  # for testing (comment this line out for production)
+"""
+Flag for WebAssembly platform.
+"""
+
+if not IS_WASM:
+    import numexpr
 
 from .version import __version__
 
@@ -100,6 +109,7 @@ from .blosc2_ext import (
     GLOBAL_REGISTERED_CODECS_STOP,
     MAX_BLOCKSIZE,
     MAX_BUFFERSIZE,
+    MAX_DIM,
     MAX_OVERHEAD,
     MAX_TYPESIZE,
     MIN_HEADER_LENGTH,
@@ -200,7 +210,9 @@ nthreads = min(nthreads, 64)
 # Experiments say that, when using a large number of threads, it is better to not use them all
 if nthreads > 16:
     nthreads -= nthreads // 8
-numexpr.set_num_threads(nthreads)
+if not IS_WASM:
+    # WASM does not support threading
+    numexpr.set_num_threads(nthreads)
 
 # This import must be before ndarray and schunk
 from .storage import (  # noqa: I001
@@ -236,6 +248,10 @@ from .ndarray import (
     ones,
     full,
     save,
+    matmul,
+    permute_dims,
+    transpose,
+    matrix_transpose,
 )
 
 from .c2array import c2context, C2Array, URLPath
@@ -254,7 +270,6 @@ from .proxy import Proxy, ProxySource, ProxyNDSource, ProxyNDField, SimpleProxy,
 
 from .schunk import SChunk, open
 
-
 # Registry for postfilters
 postfilter_funcs = {}
 """
